<?php

namespace LakeDrops\Drupal8ScaffoldDeveloper;

use Composer\Composer;
use Composer\EventDispatcher\EventSubscriberInterface;
use Composer\IO\IOInterface;
use Composer\Plugin\PluginInterface;
use Composer\Script\Event;
use Composer\Script\ScriptEvents;

/**
 * Composer plugin for handling drupal scaffold.
 */
class Plugin implements PluginInterface, EventSubscriberInterface {

  /**
   * The handler object for events.
   *
   * @var \LakeDrops\Drupal8ScaffoldDeveloper\Handler
   */
  protected $handler;

  /**
   * {@inheritdoc}
   */
  public function activate(Composer $composer, IOInterface $io) {
    $this->handler = new Handler($composer, $io);
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return array(
      ScriptEvents::POST_CREATE_PROJECT_CMD => 'postCreateProject',
    );
  }

  /**
   * Post create project event callback.
   *
   * @param \Composer\Script\Event $event
   *   The event that triggered the plugin.
   */
  public function postCreateProject(Event $event) {
    $this->handler->setupLakeDropsProject($event);
  }

  /**
   * Callback to setup the project.
   *
   * @param \Composer\Script\Event $event
   *   The event that triggered the plugin.
   */
  public static function scaffold(Event $event) {
    $handler = new Handler($event->getComposer(), $event->getIO());
    $handler->setupLakeDropsProject($event);
  }

}
